==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1EmptyDirVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1EmptyDirVolumeSourceFluentImpl<A extends V1EmptyDirVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1EmptyDirVolumeSourceFluent<A>{

    private String medium;
    private String sizeLimit;

    public V1EmptyDirVolumeSourceFluentImpl(){
    }
    public V1EmptyDirVolumeSourceFluentImpl(V1EmptyDirVolumeSource instance){
            this.withMedium(instance.getMedium());

            this.withSizeLimit(instance.getSizeLimit());

    }

    public String getMedium(){
            return this.medium;
    }

    public A withMedium(String medium){
            this.medium=medium; return (A) this;
    }

    public Boolean hasMedium(){
            return this.medium != null;
    }

    public String getSizeLimit(){
            return this.sizeLimit;
    }

    public A withSizeLimit(String sizeLimit){
            this.sizeLimit=sizeLimit; return (A) this;
    }

    public Boolean hasSizeLimit(){
            return this.sizeLimit != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1EmptyDirVolumeSourceFluentImpl that = (V1EmptyDirVolumeSourceFluentImpl) o;
            if (medium != null ? !medium.equals(that.medium) :that.medium != null) return false;
            if (sizeLimit != null ? !sizeLimit.equals(that.sizeLimit) :that.sizeLimit != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1EmptyDirVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1EmptyDirVolumeSourceFluentImpl<A extends V1EmptyDirVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1EmptyDirVolumeSourceFluent<A>{

    private String medium;
    private String sizeLimit;

    public V1EmptyDirVolumeSourceFluentImpl(){
    }
    public V1EmptyDirVolumeSourceFluentImpl(V1EmptyDirVolumeSource instance){
            this.withMedium(instance.getMedium());

            this.withSizeLimit(instance.getSizeLimit());

    }

    public String getMedium(){
            return this.medium;
    }

    public A withMedium(String medium){
            this.medium=medium; return (A) this;
    }

    public Boolean hasMedium(){
            return this.medium != null;
    }

    public A withNewMedium(String arg1){
            return (A)withMedium(new String(arg1));
    }

    public A withNewMedium(StringBuilder arg1){
            return (A)withMedium(new String(arg1));
    }

    public A withNewMedium(StringBuffer arg1){
            return (A)withMedium(new String(arg1));
    }

    public String getSizeLimit(){
            return this.sizeLimit;
    }

    public A withSizeLimit(String sizeLimit){
            this.sizeLimit=sizeLimit; return (A) this;
    }

    public Boolean hasSizeLimit(){
            return this.sizeLimit != null;
    }

    public A withNewSizeLimit(String arg1){
            return (A)withSizeLimit(new String(arg1));
    }

    public A withNewSizeLimit(StringBuilder arg1){
            return (A)withSizeLimit(new String(arg1));
    }

    public A withNewSizeLimit(StringBuffer arg1){
            return (A)withSizeLimit(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1EmptyDirVolumeSourceFluentImpl that = (V1EmptyDirVolumeSourceFluentImpl) o;
            if (medium != null ? !medium.equals(that.medium) :that.medium != null) return false;
            if (sizeLimit != null ? !sizeLimit.equals(that.sizeLimit) :that.sizeLimit != null) return false;
            return true;
    }




}
